*==
*=====
*=========
*============= Regressions by poverty levels
use "/Users/danielrodriguezsegura/Box Sync/Personal research/Costa Rica - 1st grade transition and literacy/Data/Clean data/Ready for regs/Full clean data.dta", clear

* Setting important globals
global output "/Users/danielrodriguezsegura/Box Sync/Personal research/Costa Rica - 1st grade transition and literacy/Preliminary exploration/Regressions"
global controls "rural stud_teacher_ratio share_female_stud share_female_teacher health_index join_infra_index"
global fe "i.year i.grade i.province_enc i.circuit_enc"

* Create the variable indicating low SES
egen median_pov=median(percent_underweight)
gen poor=0
replace poor=1 if percent_underweight>median_pov


*============= 1st grade
cls
preserve

* Keep only public schools
drop if public==0
drop if year>2017


* Gen a pre/post variable
gen post=0
replace post=1 if year>2013

* Gen a variable for grades that are affected
gen treated=0
replace treated=1 if grade==1
drop if grade==2 | grade==3 | grade==4

* Interaction variable (the coefficient of interest will be on this variable)
gen did=treated*post

* Labeling the variables
do "/Users/${user}/Box Sync/GitHub/grade_retention/Section 9999 - Labeling"

* Using counts as the y-var
eststo clear
eststo: reg y_var_aplaz_fail did post treated $fe $controls if poor==1, vce(cluster code) 
eststo: reg y_var_aplaz_fail did post treated $fe $controls if poor==0, vce(cluster code) 

eststo: reg y_var_fail did post treated $fe $controls if poor==1, vce(cluster code)
eststo: reg y_var_fail did post treated $fe $controls if poor==0, vce(cluster code)

eststo: reg y_var_aplaz did post treated $fe $controls if poor==1, vce(cluster code)
eststo: reg y_var_aplaz did post treated $fe $controls if poor==0, vce(cluster code)

eststo: reg y_var_dropout did post treated $fe $controls if poor==1, vce(cluster code)
eststo: reg y_var_dropout did post treated $fe $controls if poor==0, vce(cluster code)


esttab using "/${output}/First_grade_basic_pov.tex", ///
indicate("Grade FE=*grade" "School district FE=*circuit_enc" "Province FE=*province_enc" "Year FE= *year" "Controls= $controls") ///
mtitles("\shortstack{Defered or held back\\Low SES}" "\shortstack{Defered or held back\\Other SES}" "\shortstack{Held back\\Low SES}" "\shortstack{Held back\\Other SES}" "\shortstack{Defered\\Low SES}" "\shortstack{Defered\\Other SES}" "\shortstack{Dropout\\Low SES}" "\shortstack{Dropout\\Other SES}") ///label se noobs keep(did post treated) b(2) se(1) star(* 0.1 ** 0.05 *** 0.01) nocon subst( htbp H [1em] [0.5em] _ \_) replace

restore


*============= 2nd grade
cls
preserve
* Keep only public schools
drop if public==0
drop if year>2017

* Gen a pre/post variable
gen post=0
replace post=1 if year>2014

* Gen a variable for grades that are affected
gen treated=0
replace treated=1 if grade==2
drop if grade==1 | grade==3 | grade==4

* Interaction variable (the coefficient of interest will be on this variable)
gen did=treated*post

* Labeling the variables
do "/Users/${user}/Box Sync/GitHub/grade_retention/Section 9999 - Labeling"

* Using counts as the y-var
eststo clear
eststo: reg y_var_aplaz_fail did post treated $fe $controls if poor==1, vce(cluster code) 
eststo: reg y_var_aplaz_fail did post treated $fe $controls if poor==0, vce(cluster code) 

eststo: reg y_var_fail did post treated $fe $controls if poor==1, vce(cluster code)
eststo: reg y_var_fail did post treated $fe $controls if poor==0, vce(cluster code)

eststo: reg y_var_aplaz did post treated $fe $controls if poor==1, vce(cluster code)
eststo: reg y_var_aplaz did post treated $fe $controls if poor==0, vce(cluster code)

eststo: reg y_var_dropout did post treated $fe $controls if poor==1, vce(cluster code)
eststo: reg y_var_dropout did post treated $fe $controls if poor==0, vce(cluster code)

esttab using "/${output}/Second_grade_basic_pov.tex", ///
indicate("Grade FE=*grade" "School district FE=*circuit_enc" "Province FE=*province_enc" "Year FE= *year" "Controls= $controls") ///
mtitles("\shortstack{Defered or held back\\Low SES}" "\shortstack{Defered or held back\\Other SES}" "\shortstack{Held back\\Low SES}" "\shortstack{Held back\\Other SES}" "\shortstack{Defered\\Low SES}" "\shortstack{Defered\\Other SES}" "\shortstack{Dropout\\Low SES}" "\shortstack{Dropout\\Other SES}") ///label se noobs keep(did post treated) b(2) se(1) star(* 0.1 ** 0.05 *** 0.01) nocon subst( htbp H [1em] [0.5em] _ \_) replace

restore


*============= 3rd grade
cls
preserve

* Keep only public schools
drop if public==0
drop if year>2017

* Gen a pre/post variable
gen post=0
replace post=1 if year>2015

* Gen a variable for grades that are affected
gen treated=0
replace treated=1 if grade==3
drop if grade==1 | grade==2 | grade==4

* Interaction variable (the coefficient of interest will be on this variable)
gen did=treated*post

* Labeling the variables
do "/Users/${user}/Box Sync/GitHub/grade_retention/Section 9999 - Labeling"

* Using counts as the y-var
eststo clear
eststo: reg y_var_aplaz_fail did post treated $fe $controls if poor==1, vce(cluster code) 
eststo: reg y_var_aplaz_fail did post treated $fe $controls if poor==0, vce(cluster code) 

eststo: reg y_var_fail did post treated $fe $controls if poor==1, vce(cluster code)
eststo: reg y_var_fail did post treated $fe $controls if poor==0, vce(cluster code)

eststo: reg y_var_aplaz did post treated $fe $controls if poor==1, vce(cluster code)
eststo: reg y_var_aplaz did post treated $fe $controls if poor==0, vce(cluster code)

eststo: reg y_var_dropout did post treated $fe $controls if poor==1, vce(cluster code)
eststo: reg y_var_dropout did post treated $fe $controls if poor==0, vce(cluster code)


esttab using "/${output}/Third_grade_basic_pov.tex", ///
indicate("Grade FE=*grade" "School district FE=*circuit_enc" "Province FE=*province_enc" "Year FE= *year" "Controls= $controls") ///
mtitles("\shortstack{Defered or held back\\Low SES}" "\shortstack{Defered or held back\\Other SES}" "\shortstack{Held back\\Low SES}" "\shortstack{Held back\\Other SES}" "\shortstack{Defered\\Low SES}" "\shortstack{Defered\\Other SES}" "\shortstack{Dropout\\Low SES}" "\shortstack{Dropout\\Other SES}") ///label se noobs keep(did post treated) b(2) se(1) star(* 0.1 ** 0.05 *** 0.01) nocon subst( htbp H [1em] [0.5em] _ \_) replace

restore


*============= 4th grade
cls
preserve

* Keep only public schools
drop if public==0
drop if year>2017

* Gen a pre/post variable
gen post=0
replace post=1 if year>2016

* Gen a variable for grades that are affected
gen treated=0
replace treated=1 if grade==4
drop if grade==1 | grade==2 | grade==3

* Interaction variable (the coefficient of interest will be on this variable)
gen did=treated*post

* Labeling the variables
do "/Users/${user}/Box Sync/GitHub/grade_retention/Section 9999 - Labeling"

* Using counts as the y-var
eststo clear
eststo: reg y_var_aplaz_fail did post treated $fe $controls if poor==1, vce(cluster code) 
eststo: reg y_var_aplaz_fail did post treated $fe $controls if poor==0, vce(cluster code) 

eststo: reg y_var_fail did post treated $fe $controls if poor==1, vce(cluster code)
eststo: reg y_var_fail did post treated $fe $controls if poor==0, vce(cluster code)

eststo: reg y_var_aplaz did post treated $fe $controls if poor==1, vce(cluster code)
eststo: reg y_var_aplaz did post treated $fe $controls if poor==0, vce(cluster code)

eststo: reg y_var_dropout did post treated $fe $controls if poor==1, vce(cluster code)
eststo: reg y_var_dropout did post treated $fe $controls if poor==0, vce(cluster code)


esttab using "/${output}/Fourth_grade_basic_pov.tex", ///
indicate("Grade FE=*grade" "School district FE=*circuit_enc" "Province FE=*province_enc" "Year FE= *year" "Controls= $controls") ///
mtitles("\shortstack{Defered or held back\\Low SES}" "\shortstack{Defered or held back\\Other SES}" "\shortstack{Held back\\Low SES}" "\shortstack{Held back\\Other SES}" "\shortstack{Defered\\Low SES}" "\shortstack{Defered\\Other SES}" "\shortstack{Dropout\\Low SES}" "\shortstack{Dropout\\Other SES}") ///
label se noobs keep(did post treated) b(2) se(1) star(* 0.1 ** 0.05 *** 0.01) nocon subst( htbp H [1em] [0.5em] _ \_) replace

restore
